@@ -2,7 +2,7 @@ use std::{fmt::Debug, panic::panic_any};
 
 use async_std::task::block_on;
 use isahc::{AsyncBody as IsahcAsyncBody, AsyncReadResponseExt, Body as IsahcBody, Error as IsahcError, ReadResponseExt, Response as IsahcResponse};
-use serde::{Serialize, de::DeserializeOwned};
+use serde::{de::DeserializeOwned, Serialize};
 
 use super::super::{
     AsserhttpBody,
